# INDIpy

INDIpy is an open source Python implementation of the INDI (Instrument Neutral Distributed Interface) protocol. It can be used to:
* implement custom device drivers which will be run as subprocess controlled by `indiserver` along with drivers included in [INDI Library](http://indilib.org)
* implement custom INDI server
* implement client software

## Examples

You can find docker-based examples [here](../../tree/master/docker-examples/).

## Resources

INDI Protocol white paper: http://www.clearskyinstitute.com/INDI/INDI.pdf

INDI Project: http://indilib.org
